from setuptools import setup, find_packages
setup(name="SqlAlchemyUtil",
      version="0.1",
      packages=find_packages(where="."),
      install_requires=['six', 'sqlalchemy', 'MessageProcessor'],
      url="http://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br"
)